package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.Constants;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/CodeException.class */
public final class CodeException implements Cloneable, Node, Constants {
    static final CodeException[] EMPTY_CODE_EXCEPTION_ARRAY = new CodeException[0];
    private int startPc;
    private int endPc;
    private int handlerPc;
    private int catchType;

    public CodeException(CodeException c) {
        this(c.getStartPC(), c.getEndPC(), c.getHandlerPC(), c.getCatchType());
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public CodeException(DataInput file) throws IOException {
        this(file.readUnsignedShort(), file.readUnsignedShort(), file.readUnsignedShort(), file.readUnsignedShort());
    }

    public CodeException(int startPc, int endPc, int handlerPc, int catchType) {
        this.startPc = startPc;
        this.endPc = endPc;
        this.handlerPc = handlerPc;
        this.catchType = catchType;
    }

    @Override // org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitCodeException(this);
    }

    public CodeException copy() {
        try {
            return (CodeException) clone();
        } catch (CloneNotSupportedException e) {
            return null;
        }
    }

    public void dump(DataOutputStream file) throws IOException {
        file.writeShort(this.startPc);
        file.writeShort(this.endPc);
        file.writeShort(this.handlerPc);
        file.writeShort(this.catchType);
    }

    public int getCatchType() {
        return this.catchType;
    }

    public int getEndPC() {
        return this.endPc;
    }

    public int getHandlerPC() {
        return this.handlerPc;
    }

    public int getStartPC() {
        return this.startPc;
    }

    public void setCatchType(int catchType) {
        this.catchType = catchType;
    }

    public void setEndPC(int endPc) {
        this.endPc = endPc;
    }

    public void setHandlerPC(int handlerPc) {
        this.handlerPc = handlerPc;
    }

    public void setStartPC(int startPc) {
        this.startPc = startPc;
    }

    public String toString() {
        return "CodeException(startPc = " + this.startPc + ", endPc = " + this.endPc + ", handlerPc = " + this.handlerPc + ", catchType = " + this.catchType + ")";
    }

    public String toString(ConstantPool cp) {
        return toString(cp, true);
    }

    public String toString(ConstantPool cp, boolean verbose) {
        String str;
        if (this.catchType == 0) {
            str = "<Any exception>(0)";
        } else {
            str = Utility.compactClassName(cp.getConstantString(this.catchType, (byte) 7), false) + (verbose ? "(" + this.catchType + ")" : "");
        }
        return this.startPc + "\t" + this.endPc + "\t" + this.handlerPc + "\t" + str;
    }
}
